==> HandBrake-0.9.1.tar.gz: HandBrake/win/C#/frmDvdInfo.cs <==
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;


namespace Handbrake
{
    public partial class frmDvdInfo : Form
    {
        /// <summary>
        /// This window should be used to display the RAW output of the handbrake CLI which is produced during the scan.
        /// </summary>
        public frmDvdInfo()
        {
            InitializeComponent();
            this.rtf_dvdInfo.Text = string.Empty;
            
        }

        /*public void HandleParsedData(object Sender, string Data)
        {
            if (this.InvokeRequired)
            {
                this.BeginInvoke(new Parsing.DataReadEventHandler(HandleParsedData), new object[] { Sender, Data });
                return;
            }
            this.rtf_dvdInfo.AppendText(Data + System.Environment.NewLine);
        }*/

        private void btn_close_Click(object sender, EventArgs e)
        {
            this.Hide();
        }

        private void frmDvdInfo_Load(object sender, EventArgs e)
        {
            this.rtf_dvdInfo.Text = string.Empty;
            readFile();
        }

        private void readFile()
        {
            try
            {
                string appPath = Application.StartupPath.ToString();
                appPath = appPath + "\\";
                StreamReader sr = new StreamReader(appPath + "dvdinfo.dat");

                string line = sr.ReadLine();

                while (line != null)
                {
                    this.rtf_dvdInfo.AppendText(line + System.Environment.NewLine);
                    line = sr.ReadLine();
                }
                sr.Close();
            }
            catch (Exception)
            {
                // Don't do anything
            }
        }

        /*protected override void OnClosing(CancelEventArgs e)
        {
            e.Cancel = true;
            this.Hide();
            base.OnClosing(e);
        }*/

    }
}

==> HandBrake-0.9.2.tar.gz: HandBrake/win/C#/frmDvdInfo.cs <==
/*  frmDvdInfo.cs $
 	
 	   This file is part of the HandBrake source code.
 	   Homepage: <http://handbrake.m0k.org/>.
 	   It may be used under the terms of the GNU General Public License. */

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;


namespace Handbrake
{
    public partial class frmDvdInfo : Form
    {
        /// <summary>
        /// This window should be used to display the RAW output of the handbrake CLI which is produced during the scan.
        /// </summary>
        public frmDvdInfo()
        {
            InitializeComponent();
            this.rtf_dvdInfo.Text = string.Empty;     
        }

        private void btn_close_Click(object sender, EventArgs e)
        {
             this.Hide();
        }

        private void frmDvdInfo_Load(object sender, EventArgs e)
        {
            this.rtf_dvdInfo.Text = string.Empty;
            readFile();
        }

        private void readFile()
        {
            try
            {
                string dvdInfoPath = Path.Combine(Path.GetTempPath(), "dvdinfo.dat");
                StreamReader sr = new StreamReader(dvdInfoPath);

                string line = sr.ReadLine();

                while (line != null)
                {
                    this.rtf_dvdInfo.AppendText(line + System.Environment.NewLine);
                    line = sr.ReadLine();
                }
                sr.Close();
            }
            catch (Exception)
            {
                // Don't do anything
            }
        }

        private void btn_copy_Click(object sender, EventArgs e)
        {
            if (rtf_dvdInfo.Text != "")
                Clipboard.SetText(rtf_dvdInfo.Text, TextDataFormat.Text);
        }
    }
}
